@@ -1,21 +1,21 @@
 // -*- c++ -*-
-/* $Id: comboboxtext.cc,v 1.8 2005/05/03 17:01:16 murrayc Exp $ */
+/* $Id: comboboxtext.cc 1082 2009-01-19 17:55:19Z murrayc $ */
 
 /* 
  *
  * Copyright 2003 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -24,8 +24,7 @@
 
 #include <gtkmm/liststore.h>
 #include <gtkmm/cellrenderertext.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcelllayout.h>
+#include <gtk/gtk.h>
 
 namespace Gtk
 {
